@@ -2,6 +2,19 @@ import time
 from contextlib import contextmanager
 
 from functools import wraps
+from tqdm import tqdm
+
+
+class Tqmp(tqdm):
+    def __init__(self, **kwargs):
+        tqdm.__init__(self, **kwargs)
+
+        self.last_size = 0
+
+    def progress(self, n):
+        self.update(n - self.last_size)
+
+        self.last_size = n
 
 
 class Potency:
